echo "hello"
echo "world"
echo "hello from job 1"
echo "hello from job 2"

wait

#HPC mem=24GB
#HPC module=module1 module2

echo "new commands"
echo "hello from job 3"

wait

#HPC mem
#HPC cpus_per_task=12
#HPC module=module1/1.2.3 module2
#HPC walltime=15:00:00

echo "new commands"
echo "hello from job 3"
