#!/bin/bash
#
#PBS -N job_3
#PBS -q adserial
#PBS -l nodes=1:ppn=12
#PBS -eo localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_11T06_41_06/job_3.log





    
module load module1/1.2.3 module2
    


cd /home/jillian/projects/perl/HPC-Runner-PBS/example
mcerunner.pl --procs 4 --infile /home/jillian/projects/perl/HPC-Runner-PBS/example/logs/job_3.in --outdir /home/jillian/projects/perl/HPC-Runner-PBS/example/logs --logname job_3
